---
title: schema for humans
description: config schema humanified
---

- [1. Property `Rovr Config > interface`](#interface)
  - [1.1. Property `Rovr Config > interface > tooltips`](#interface_tooltips)
  - [1.2. Property `Rovr Config > interface > nerd_font`](#interface_nerd_font)
  - [1.3. Property `Rovr Config > interface > show_progress_eta`](#interface_show_progress_eta)
  - [1.4. Property `Rovr Config > interface > show_progress_percentage`](#interface_show_progress_percentage)
  - [1.5. Property `Rovr Config > interface > truncate_progress_file_path`](#interface_truncate_progress_file_path)
  - [1.6. Property `Rovr Config > interface > preview_error`](#interface_preview_error)
  - [1.7. Property `Rovr Config > interface > preview_binary`](#interface_preview_binary)
  - [1.8. Property `Rovr Config > interface > preview_start`](#interface_preview_start)
  - [1.9. Property `Rovr Config > interface > clock`](#interface_clock)
    - [1.9.1. Property `Rovr Config > interface > clock > enabled`](#interface_clock_enabled)
    - [1.9.2. Property `Rovr Config > interface > clock > align`](#interface_clock_align)
- [2. Property `Rovr Config > settings`](#settings)
  - [2.1. Property `Rovr Config > settings > use_recycle_bin`](#settings_use_recycle_bin)
  - [2.2. Property `Rovr Config > settings > copy_includes_metadata`](#settings_copy_includes_metadata)
  - [2.3. Property `Rovr Config > settings > image_protocol`](#settings_image_protocol)
  - [2.4. Property `Rovr Config > settings > preview_full`](#settings_preview_full)
  - [2.5. Property `Rovr Config > settings > allow_tab_nav`](#settings_allow_tab_nav)
  - [2.6. Property `Rovr Config > settings > append_new_tabs`](#settings_append_new_tabs)
  - [2.7. Property `Rovr Config > settings > cd_on_quit`](#settings_cd_on_quit)
- [3. Property `Rovr Config > metadata`](#metadata)
  - [3.1. Property `Rovr Config > metadata > fields`](#metadata_fields)
    - [3.1.1. Rovr Config > metadata > fields > fields items](#metadata_fields_items)
  - [3.2. Property `Rovr Config > metadata > datetime_format`](#metadata_datetime_format)
  - [3.3. Property `Rovr Config > metadata > filesize_decimals`](#metadata_filesize_decimals)
  - [3.4. Property `Rovr Config > metadata > filesize_suffix`](#metadata_filesize_suffix)
- [4. Property `Rovr Config > icons`](#icons)
  - [4.1. Property `Rovr Config > icons > files`](#icons_files)
    - [4.1.1. Rovr Config > icons > files > files items](#icons_files_items)
      - [4.1.1.1. Property `Rovr Config > icons > files > files items > pattern`](#icons_files_items_pattern)
      - [4.1.1.2. Property `Rovr Config > icons > files > files items > match_type`](#icons_files_items_match_type)
      - [4.1.1.3. Property `Rovr Config > icons > files > files items > icon`](#icons_files_items_icon)
      - [4.1.1.4. Property `Rovr Config > icons > files > files items > color`](#icons_files_items_color)
  - [4.2. Property `Rovr Config > icons > folders`](#icons_folders)
    - [4.2.1. Rovr Config > icons > folders > folders items](#icons_folders_items)
      - [4.2.1.1. Property `Rovr Config > icons > folders > folders items > pattern`](#icons_folders_items_pattern)
      - [4.2.1.2. Property `Rovr Config > icons > folders > folders items > match_type`](#icons_folders_items_match_type)
      - [4.2.1.3. Property `Rovr Config > icons > folders > folders items > icon`](#icons_folders_items_icon)
      - [4.2.1.4. Property `Rovr Config > icons > folders > folders items > color`](#icons_folders_items_color)
- [5. Property `Rovr Config > theme`](#theme)
  - [5.1. Property `Rovr Config > theme > default`](#theme_default)
  - [5.2. Property `Rovr Config > theme > transparent`](#theme_transparent)
- [6. Property `Rovr Config > custom_theme`](#custom_theme)
  - [6.1. Rovr Config > custom_theme > custom_theme items](#custom_theme_items)
    - [6.1.1. Property `Rovr Config > custom_theme > custom_theme items > name`](#custom_theme_items_name)
    - [6.1.2. Property `Rovr Config > custom_theme > custom_theme items > primary`](#custom_theme_items_primary)
    - [6.1.3. Property `Rovr Config > custom_theme > custom_theme items > secondary`](#custom_theme_items_secondary)
    - [6.1.4. Property `Rovr Config > custom_theme > custom_theme items > warning`](#custom_theme_items_warning)
    - [6.1.5. Property `Rovr Config > custom_theme > custom_theme items > error`](#custom_theme_items_error)
    - [6.1.6. Property `Rovr Config > custom_theme > custom_theme items > success`](#custom_theme_items_success)
    - [6.1.7. Property `Rovr Config > custom_theme > custom_theme items > accent`](#custom_theme_items_accent)
    - [6.1.8. Property `Rovr Config > custom_theme > custom_theme items > foreground`](#custom_theme_items_foreground)
    - [6.1.9. Property `Rovr Config > custom_theme > custom_theme items > background`](#custom_theme_items_background)
    - [6.1.10. Property `Rovr Config > custom_theme > custom_theme items > surface`](#custom_theme_items_surface)
    - [6.1.11. Property `Rovr Config > custom_theme > custom_theme items > panel`](#custom_theme_items_panel)
    - [6.1.12. Property `Rovr Config > custom_theme > custom_theme items > is_dark`](#custom_theme_items_is_dark)
    - [6.1.13. Property `Rovr Config > custom_theme > custom_theme items > variables`](#custom_theme_items_variables)
- [7. Property `Rovr Config > keybinds`](#keybinds)
  - [7.1. Property `Rovr Config > keybinds > toggle_pin`](#keybinds_toggle_pin)
    - [7.1.1. Rovr Config > keybinds > toggle_pin > toggle_pin items](#keybinds_toggle_pin_items)
  - [7.2. Property `Rovr Config > keybinds > toggle_pinned_sidebar`](#keybinds_toggle_pinned_sidebar)
    - [7.2.1. Rovr Config > keybinds > toggle_pinned_sidebar > toggle_pinned_sidebar items](#keybinds_toggle_pinned_sidebar_items)
  - [7.3. Property `Rovr Config > keybinds > toggle_preview_sidebar`](#keybinds_toggle_preview_sidebar)
    - [7.3.1. Rovr Config > keybinds > toggle_preview_sidebar > toggle_preview_sidebar items](#keybinds_toggle_preview_sidebar_items)
  - [7.4. Property `Rovr Config > keybinds > toggle_footer`](#keybinds_toggle_footer)
    - [7.4.1. Rovr Config > keybinds > toggle_footer > toggle_footer items](#keybinds_toggle_footer_items)
  - [7.5. Property `Rovr Config > keybinds > focus_toggle_pinned_sidebar`](#keybinds_focus_toggle_pinned_sidebar)
    - [7.5.1. Rovr Config > keybinds > focus_toggle_pinned_sidebar > focus_toggle_pinned_sidebar items](#keybinds_focus_toggle_pinned_sidebar_items)
  - [7.6. Property `Rovr Config > keybinds > focus_file_list`](#keybinds_focus_file_list)
    - [7.6.1. Rovr Config > keybinds > focus_file_list > focus_file_list items](#keybinds_focus_file_list_items)
  - [7.7. Property `Rovr Config > keybinds > focus_toggle_preview_sidebar`](#keybinds_focus_toggle_preview_sidebar)
    - [7.7.1. Rovr Config > keybinds > focus_toggle_preview_sidebar > focus_toggle_preview_sidebar items](#keybinds_focus_toggle_preview_sidebar_items)
  - [7.8. Property `Rovr Config > keybinds > focus_toggle_path_switcher`](#keybinds_focus_toggle_path_switcher)
    - [7.8.1. Rovr Config > keybinds > focus_toggle_path_switcher > focus_toggle_path_switcher items](#keybinds_focus_toggle_path_switcher_items)
  - [7.9. Property `Rovr Config > keybinds > focus_toggle_processes`](#keybinds_focus_toggle_processes)
    - [7.9.1. Rovr Config > keybinds > focus_toggle_processes > focus_toggle_processes items](#keybinds_focus_toggle_processes_items)
  - [7.10. Property `Rovr Config > keybinds > focus_toggle_clipboard`](#keybinds_focus_toggle_clipboard)
    - [7.10.1. Rovr Config > keybinds > focus_toggle_clipboard > focus_toggle_clipboard items](#keybinds_focus_toggle_clipboard_items)
  - [7.11. Property `Rovr Config > keybinds > focus_toggle_metadata`](#keybinds_focus_toggle_metadata)
    - [7.11.1. Rovr Config > keybinds > focus_toggle_metadata > focus_toggle_metadata items](#keybinds_focus_toggle_metadata_items)
  - [7.12. Property `Rovr Config > keybinds > focus_search`](#keybinds_focus_search)
    - [7.12.1. Rovr Config > keybinds > focus_search > focus_search items](#keybinds_focus_search_items)
  - [7.13. Property `Rovr Config > keybinds > copy`](#keybinds_copy)
    - [7.13.1. Rovr Config > keybinds > copy > copy items](#keybinds_copy_items)
  - [7.14. Property `Rovr Config > keybinds > paste`](#keybinds_paste)
    - [7.14.1. Rovr Config > keybinds > paste > paste items](#keybinds_paste_items)
  - [7.15. Property `Rovr Config > keybinds > cut`](#keybinds_cut)
    - [7.15.1. Rovr Config > keybinds > cut > cut items](#keybinds_cut_items)
  - [7.16. Property `Rovr Config > keybinds > delete`](#keybinds_delete)
    - [7.16.1. Rovr Config > keybinds > delete > delete items](#keybinds_delete_items)
  - [7.17. Property `Rovr Config > keybinds > rename`](#keybinds_rename)
    - [7.17.1. Rovr Config > keybinds > rename > rename items](#keybinds_rename_items)
  - [7.18. Property `Rovr Config > keybinds > new`](#keybinds_new)
    - [7.18.1. Rovr Config > keybinds > new > new items](#keybinds_new_items)
  - [7.19. Property `Rovr Config > keybinds > toggle_all`](#keybinds_toggle_all)
    - [7.19.1. Rovr Config > keybinds > toggle_all > toggle_all items](#keybinds_toggle_all_items)
  - [7.20. Property `Rovr Config > keybinds > zip`](#keybinds_zip)
    - [7.20.1. Rovr Config > keybinds > zip > zip items](#keybinds_zip_items)
  - [7.21. Property `Rovr Config > keybinds > unzip`](#keybinds_unzip)
    - [7.21.1. Rovr Config > keybinds > unzip > unzip items](#keybinds_unzip_items)
  - [7.22. Property `Rovr Config > keybinds > up`](#keybinds_up)
    - [7.22.1. Rovr Config > keybinds > up > up items](#keybinds_up_items)
  - [7.23. Property `Rovr Config > keybinds > down`](#keybinds_down)
    - [7.23.1. Rovr Config > keybinds > down > down items](#keybinds_down_items)
  - [7.24. Property `Rovr Config > keybinds > up_tree`](#keybinds_up_tree)
    - [7.24.1. Rovr Config > keybinds > up_tree > up_tree items](#keybinds_up_tree_items)
  - [7.25. Property `Rovr Config > keybinds > down_tree`](#keybinds_down_tree)
    - [7.25.1. Rovr Config > keybinds > down_tree > down_tree items](#keybinds_down_tree_items)
  - [7.26. Property `Rovr Config > keybinds > page_up`](#keybinds_page_up)
    - [7.26.1. Rovr Config > keybinds > page_up > page_up items](#keybinds_page_up_items)
  - [7.27. Property `Rovr Config > keybinds > page_down`](#keybinds_page_down)
    - [7.27.1. Rovr Config > keybinds > page_down > page_down items](#keybinds_page_down_items)
  - [7.28. Property `Rovr Config > keybinds > home`](#keybinds_home)
    - [7.28.1. Rovr Config > keybinds > home > home items](#keybinds_home_items)
  - [7.29. Property `Rovr Config > keybinds > end`](#keybinds_end)
    - [7.29.1. Rovr Config > keybinds > end > end items](#keybinds_end_items)
  - [7.30. Property `Rovr Config > keybinds > hist_previous`](#keybinds_hist_previous)
    - [7.30.1. Rovr Config > keybinds > hist_previous > hist_previous items](#keybinds_hist_previous_items)
  - [7.31. Property `Rovr Config > keybinds > hist_next`](#keybinds_hist_next)
    - [7.31.1. Rovr Config > keybinds > hist_next > hist_next items](#keybinds_hist_next_items)
  - [7.32. Property `Rovr Config > keybinds > toggle_visual`](#keybinds_toggle_visual)
    - [7.32.1. Rovr Config > keybinds > toggle_visual > toggle_visual items](#keybinds_toggle_visual_items)
  - [7.33. Property `Rovr Config > keybinds > select_up`](#keybinds_select_up)
    - [7.33.1. Rovr Config > keybinds > select_up > select_up items](#keybinds_select_up_items)
  - [7.34. Property `Rovr Config > keybinds > select_down`](#keybinds_select_down)
    - [7.34.1. Rovr Config > keybinds > select_down > select_down items](#keybinds_select_down_items)
  - [7.35. Property `Rovr Config > keybinds > select_page_up`](#keybinds_select_page_up)
    - [7.35.1. Rovr Config > keybinds > select_page_up > select_page_up items](#keybinds_select_page_up_items)
  - [7.36. Property `Rovr Config > keybinds > select_page_down`](#keybinds_select_page_down)
    - [7.36.1. Rovr Config > keybinds > select_page_down > select_page_down items](#keybinds_select_page_down_items)
  - [7.37. Property `Rovr Config > keybinds > select_home`](#keybinds_select_home)
    - [7.37.1. Rovr Config > keybinds > select_home > select_home items](#keybinds_select_home_items)
  - [7.38. Property `Rovr Config > keybinds > select_end`](#keybinds_select_end)
    - [7.38.1. Rovr Config > keybinds > select_end > select_end items](#keybinds_select_end_items)
  - [7.39. Property `Rovr Config > keybinds > tab_next`](#keybinds_tab_next)
    - [7.39.1. Rovr Config > keybinds > tab_next > tab_next items](#keybinds_tab_next_items)
  - [7.40. Property `Rovr Config > keybinds > tab_previous`](#keybinds_tab_previous)
    - [7.40.1. Rovr Config > keybinds > tab_previous > tab_previous items](#keybinds_tab_previous_items)
  - [7.41. Property `Rovr Config > keybinds > tab_new`](#keybinds_tab_new)
    - [7.41.1. Rovr Config > keybinds > tab_new > tab_new items](#keybinds_tab_new_items)
  - [7.42. Property `Rovr Config > keybinds > tab_close`](#keybinds_tab_close)
    - [7.42.1. Rovr Config > keybinds > tab_close > tab_close items](#keybinds_tab_close_items)
  - [7.43. Property `Rovr Config > keybinds > preview_scroll_left`](#keybinds_preview_scroll_left)
    - [7.43.1. Rovr Config > keybinds > preview_scroll_left > preview_scroll_left items](#keybinds_preview_scroll_left_items)
  - [7.44. Property `Rovr Config > keybinds > preview_scroll_right`](#keybinds_preview_scroll_right)
    - [7.44.1. Rovr Config > keybinds > preview_scroll_right > preview_scroll_right items](#keybinds_preview_scroll_right_items)
  - [7.45. Property `Rovr Config > keybinds > preview_select_right`](#keybinds_preview_select_right)
    - [7.45.1. Rovr Config > keybinds > preview_select_right > preview_select_right items](#keybinds_preview_select_right_items)
  - [7.46. Property `Rovr Config > keybinds > preview_select_left`](#keybinds_preview_select_left)
    - [7.46.1. Rovr Config > keybinds > preview_select_left > preview_select_left items](#keybinds_preview_select_left_items)
- [8. Property `Rovr Config > plugins`](#plugins)
  - [8.1. Property `Rovr Config > plugins > zoxide`](#plugins_zoxide)
    - [8.1.1. Property `Rovr Config > plugins > zoxide > enabled`](#plugins_zoxide_enabled)
    - [8.1.2. Property `Rovr Config > plugins > zoxide > keybinds`](#plugins_zoxide_keybinds)
      - [8.1.2.1. Rovr Config > plugins > zoxide > keybinds > keybinds items](#plugins_zoxide_keybinds_items)
  - [8.2. Property `Rovr Config > plugins > bat`](#plugins_bat)
    - [8.2.1. Property `Rovr Config > plugins > bat > enabled`](#plugins_bat_enabled)
    - [8.2.2. Property `Rovr Config > plugins > bat > executable`](#plugins_bat_executable)
    - [8.2.3. Property `Rovr Config > plugins > bat > show_line_numbers`](#plugins_bat_show_line_numbers)
  - [8.3. Property `Rovr Config > plugins > editor`](#plugins_editor)
    - [8.3.1. Property `Rovr Config > plugins > editor > enabled`](#plugins_editor_enabled)
    - [8.3.2. Property `Rovr Config > plugins > editor > file_executable`](#plugins_editor_file_executable)
    - [8.3.3. Property `Rovr Config > plugins > editor > folder_executable`](#plugins_editor_folder_executable)
    - [8.3.4. Property `Rovr Config > plugins > editor > keybinds`](#plugins_editor_keybinds)
      - [8.3.4.1. Rovr Config > plugins > editor > keybinds > keybinds items](#plugins_editor_keybinds_items)
  - [8.4. Property `Rovr Config > plugins > zen_mode`](#plugins_zen_mode)
    - [8.4.1. Property `Rovr Config > plugins > zen_mode > enabled`](#plugins_zen_mode_enabled)
    - [8.4.2. Property `Rovr Config > plugins > zen_mode > keybinds`](#plugins_zen_mode_keybinds)
      - [8.4.2.1. Rovr Config > plugins > zen_mode > keybinds > keybinds items](#plugins_zen_mode_keybinds_items)

**Title:** Rovr Config

|                           |             |
| ------------------------- | ----------- |
| **Type**                  | `object`    |
| **Required**              | No          |
| **Additional properties** | Not allowed |

| Property                         | Type            | Title/Description                                |
| -------------------------------- | --------------- | ------------------------------------------------ |
|   [interface](#interface )       | object          |                                                  |
|   [settings](#settings )         | object          |                                                  |
|   [metadata](#metadata )         | object          |                                                  |
|   [icons](#icons )               | object          | Custom icon configurations for files and folders |
|   [theme](#theme )               | object          |                                                  |
|   [custom_theme](#custom_theme ) | array of object |                                                  |
|   [keybinds](#keybinds )         | object          |                                                  |
|   [plugins](#plugins )           | object          |                                                  |

## <a name="interface"></a>1. Property `Rovr Config > interface`

|                           |             |
| ------------------------- | ----------- |
| **Type**                  | `object`    |
| **Required**              | No          |
| **Additional properties** | Not allowed |

| Property                                                                 | Type    | Title/Description                                                                                                         |
| ------------------------------------------------------------------------ | ------- | ------------------------------------------------------------------------------------------------------------------------- |
|   [tooltips](#interface_tooltips )                                       | boolean | Show tooltips when your mouse is over a tooltip supported button.<br />This is not hot reloaded.                          |
|   [nerd_font](#interface_nerd_font )                                     | boolean | Use nerd font for rendering icons instead of weird characters and stuff.<br />Not properly hot-reloaded.                  |
|   [show_progress_eta](#interface_show_progress_eta )                     | boolean | When copying or deleting files, show an ETA for when the action will be completed.                                        |
|   [show_progress_percentage](#interface_show_progress_percentage )       | boolean | When copying or deleting files, show a percentage of how much had been completed.                                         |
|   [truncate_progress_file_path](#interface_truncate_progress_file_path ) | boolean | When the process container is using file paths, truncate the file path to only view the first and last names of the path. |
|   [preview_error](#interface_preview_error )                             | string  | If for any reason the file preview refused to show, this appears.                                                         |
|   [preview_binary](#interface_preview_binary )                           | string  | If the current file cannot be read due to an encoding issue (ie not UTF8), it will display this message.                  |
|   [preview_start](#interface_preview_start )                             | string  | This is shown when the rovr starts up. You may see it for a split second, but it will never appear afterwards.            |
|   [clock](#interface_clock )                                             | object  |                                                                                                                           |

### <a name="interface_tooltips"></a>1.1. Property `Rovr Config > interface > tooltips`

|              |           |
| ------------ | --------- |
| **Type**     | `boolean` |
| **Required** | No        |
| **Default**  | `true`    |

**Description:** Show tooltips when your mouse is over a tooltip supported button.
This is not hot reloaded.

### <a name="interface_nerd_font"></a>1.2. Property `Rovr Config > interface > nerd_font`

|              |           |
| ------------ | --------- |
| **Type**     | `boolean` |
| **Required** | No        |
| **Default**  | `false`   |

**Description:** Use nerd font for rendering icons instead of weird characters and stuff.
Not properly hot-reloaded.

### <a name="interface_show_progress_eta"></a>1.3. Property `Rovr Config > interface > show_progress_eta`

|              |           |
| ------------ | --------- |
| **Type**     | `boolean` |
| **Required** | No        |
| **Default**  | `false`   |

**Description:** When copying or deleting files, show an ETA for when the action will be completed.

### <a name="interface_show_progress_percentage"></a>1.4. Property `Rovr Config > interface > show_progress_percentage`

|              |           |
| ------------ | --------- |
| **Type**     | `boolean` |
| **Required** | No        |
| **Default**  | `false`   |

**Description:** When copying or deleting files, show a percentage of how much had been completed.

### <a name="interface_truncate_progress_file_path"></a>1.5. Property `Rovr Config > interface > truncate_progress_file_path`

|              |           |
| ------------ | --------- |
| **Type**     | `boolean` |
| **Required** | No        |
| **Default**  | `false`   |

**Description:** When the process container is using file paths, truncate the file path to only view the first and last names of the path.

### <a name="interface_preview_error"></a>1.6. Property `Rovr Config > interface > preview_error`

|              |                                                          |
| ------------ | -------------------------------------------------------- |
| **Type**     | `string`                                                 |
| **Required** | No                                                       |
| **Default**  | `"Hmm, I think this file got corrupted (or maybe not?)"` |

**Description:** If for any reason the file preview refused to show, this appears.

### <a name="interface_preview_binary"></a>1.7. Property `Rovr Config > interface > preview_binary`

|              |                                                              |
| ------------ | ------------------------------------------------------------ |
| **Type**     | `string`                                                     |
| **Required** | No                                                           |
| **Default**  | `"This file is not UTF-8 encoded, so I decline to read it."` |

**Description:** If the current file cannot be read due to an encoding issue (ie not UTF8), it will display this message.

### <a name="interface_preview_start"></a>1.8. Property `Rovr Config > interface > preview_start`

|              |                              |
| ------------ | ---------------------------- |
| **Type**     | `string`                     |
| **Required** | No                           |
| **Default**  | `"print(\"Hello, world!\")"` |

**Description:** This is shown when the rovr starts up. You may see it for a split second, but it will never appear afterwards.

### <a name="interface_clock"></a>1.9. Property `Rovr Config > interface > clock`

|                           |             |
| ------------------------- | ----------- |
| **Type**                  | `object`    |
| **Required**              | No          |
| **Additional properties** | Not allowed |

| Property                               | Type             | Title/Description                                                |
| -------------------------------------- | ---------------- | ---------------------------------------------------------------- |
|   [enabled](#interface_clock_enabled ) | boolean          | Show a clock in the tabs bar.                                    |
|   [align](#interface_clock_align )     | enum (of string) | Align the clock to either the 'right' or 'left' of the tabs bar. |

#### <a name="interface_clock_enabled"></a>1.9.1. Property `Rovr Config > interface > clock > enabled`

|              |           |
| ------------ | --------- |
| **Type**     | `boolean` |
| **Required** | No        |
| **Default**  | `true`    |

**Description:** Show a clock in the tabs bar.

#### <a name="interface_clock_align"></a>1.9.2. Property `Rovr Config > interface > clock > align`

|              |                    |
| ------------ | ------------------ |
| **Type**     | `enum (of string)` |
| **Required** | No                 |
| **Default**  | `"right"`          |

**Description:** Align the clock to either the 'right' or 'left' of the tabs bar.

Must be one of:
* "left"
* "right"

## <a name="settings"></a>2. Property `Rovr Config > settings`

|                           |             |
| ------------------------- | ----------- |
| **Type**                  | `object`    |
| **Required**              | No          |
| **Additional properties** | Not allowed |

| Property                                                      | Type             | Title/Description                                                                                                                                                      |
| ------------------------------------------------------------- | ---------------- | ---------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
|   [use_recycle_bin](#settings_use_recycle_bin )               | boolean          | When deleting a file, allow moving the file to the recycle bin.                                                                                                        |
|   [copy_includes_metadata](#settings_copy_includes_metadata ) | boolean          | When copying over a file, preserve metadata from the original file, such as creation and modification times.                                                           |
|   [image_protocol](#settings_image_protocol )                 | enum (of string) | The image protocol to use when displaying an image                                                                                                                     |
|   [preview_full](#settings_preview_full )                     | boolean          | Whether or not you want to view the full file. It sort of works, not sure why it doesnt properly work, looking into it.                                                |
|   [allow_tab_nav](#settings_allow_tab_nav )                   | boolean          | Allow navigating the main app screen with \`tab\` and \`shift+tab\`                                                                                                    |
|   [append_new_tabs](#settings_append_new_tabs )               | boolean          | Choose whether or not to append new tabs instead of inserting them.<br />\`true\` => Append to the end of the tab list.<br />\`false\` => Insert after the active tab. |
|   [cd_on_quit](#settings_cd_on_quit )                         | boolean          | When quitting rovr, write the current directory to a file, so that you can cd into it.                                                                                 |

### <a name="settings_use_recycle_bin"></a>2.1. Property `Rovr Config > settings > use_recycle_bin`

|              |           |
| ------------ | --------- |
| **Type**     | `boolean` |
| **Required** | No        |
| **Default**  | `true`    |

**Description:** When deleting a file, allow moving the file to the recycle bin.

### <a name="settings_copy_includes_metadata"></a>2.2. Property `Rovr Config > settings > copy_includes_metadata`

|              |           |
| ------------ | --------- |
| **Type**     | `boolean` |
| **Required** | No        |
| **Default**  | `true`    |

**Description:** When copying over a file, preserve metadata from the original file, such as creation and modification times.

### <a name="settings_image_protocol"></a>2.3. Property `Rovr Config > settings > image_protocol`

|              |                    |
| ------------ | ------------------ |
| **Type**     | `enum (of string)` |
| **Required** | No                 |
| **Default**  | `"Auto"`           |

**Description:** The image protocol to use when displaying an image

Must be one of:
* "Auto"
* "TGP"
* "Sixel"
* "Halfcell"
* "Unicode"

### <a name="settings_preview_full"></a>2.4. Property `Rovr Config > settings > preview_full`

|              |           |
| ------------ | --------- |
| **Type**     | `boolean` |
| **Required** | No        |
| **Default**  | `false`   |

**Description:** Whether or not you want to view the full file. It sort of works, not sure why it doesnt properly work, looking into it.

### <a name="settings_allow_tab_nav"></a>2.5. Property `Rovr Config > settings > allow_tab_nav`

|              |           |
| ------------ | --------- |
| **Type**     | `boolean` |
| **Required** | No        |
| **Default**  | `false`   |

**Description:** Allow navigating the main app screen with `tab` and `shift+tab`

### <a name="settings_append_new_tabs"></a>2.6. Property `Rovr Config > settings > append_new_tabs`

|              |           |
| ------------ | --------- |
| **Type**     | `boolean` |
| **Required** | No        |
| **Default**  | `true`    |

**Description:** Choose whether or not to append new tabs instead of inserting them.
`true` => Append to the end of the tab list.
`false` => Insert after the active tab.

### <a name="settings_cd_on_quit"></a>2.7. Property `Rovr Config > settings > cd_on_quit`

|              |           |
| ------------ | --------- |
| **Type**     | `boolean` |
| **Required** | No        |
| **Default**  | `false`   |

**Description:** When quitting rovr, write the current directory to a file, so that you can cd into it.

## <a name="metadata"></a>3. Property `Rovr Config > metadata`

|                           |             |
| ------------------------- | ----------- |
| **Type**                  | `object`    |
| **Required**              | No          |
| **Additional properties** | Not allowed |

| Property                                            | Type                      | Title/Description                                                                                                             |
| --------------------------------------------------- | ------------------------- | ----------------------------------------------------------------------------------------------------------------------------- |
|   [fields](#metadata_fields )                       | array of enum (of string) | The order of the metadata tags that you want to see in the Metadata section.                                                  |
|   [datetime_format](#metadata_datetime_format )     | string                    | The datetime format for Metadata. Refer to https://docs.python.org/3/library/datetime.html#format-codes for more information. |
|   [filesize_decimals](#metadata_filesize_decimals ) | integer                   | The number of decimals you want to see in the humanized file size                                                             |
|   [filesize_suffix](#metadata_filesize_suffix )     | enum (of string)          | The filesize suffix to follow.<br />\`decimal\`: 1024 -> 1.024kB<br />\`binary\`: 1024 -> 1KiB<br />\`gnu\`: 1024 -> 1K       |

### <a name="metadata_fields"></a>3.1. Property `Rovr Config > metadata > fields`

|              |                                                                      |
| ------------ | -------------------------------------------------------------------- |
| **Type**     | `array of enum (of string)`                                          |
| **Required** | No                                                                   |
| **Default**  | `["type", "permissions", "size", "modified", "accessed", "created"]` |

**Description:** The order of the metadata tags that you want to see in the Metadata section.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be        | Description |
| -------------------------------------- | ----------- |
| [fields items](#metadata_fields_items) |             |

#### <a name="metadata_fields_items"></a>3.1.1. Rovr Config > metadata > fields > fields items

|              |                    |
| ------------ | ------------------ |
| **Type**     | `enum (of string)` |
| **Required** | No                 |

Must be one of:
* "type"
* "permissions"
* "size"
* "modified"
* "accessed"
* "created"

### <a name="metadata_datetime_format"></a>3.2. Property `Rovr Config > metadata > datetime_format`

|              |                    |
| ------------ | ------------------ |
| **Type**     | `string`           |
| **Required** | No                 |
| **Default**  | `"%Y-%m-%d %H:%M"` |

**Description:** The datetime format for Metadata. Refer to https://docs.python.org/3/library/datetime.html#format-codes for more information.

### <a name="metadata_filesize_decimals"></a>3.3. Property `Rovr Config > metadata > filesize_decimals`

|              |           |
| ------------ | --------- |
| **Type**     | `integer` |
| **Required** | No        |
| **Default**  | `1`       |

**Description:** The number of decimals you want to see in the humanized file size

### <a name="metadata_filesize_suffix"></a>3.4. Property `Rovr Config > metadata > filesize_suffix`

|              |                    |
| ------------ | ------------------ |
| **Type**     | `enum (of string)` |
| **Required** | No                 |
| **Default**  | `"decimal"`        |

**Description:** The filesize suffix to follow.
`decimal`: 1024 -> 1.024kB
`binary`: 1024 -> 1KiB
`gnu`: 1024 -> 1K

Must be one of:
* "decimal"
* "binary"
* "gnu"

## <a name="icons"></a>4. Property `Rovr Config > icons`

|                           |             |
| ------------------------- | ----------- |
| **Type**                  | `object`    |
| **Required**              | No          |
| **Additional properties** | Not allowed |

**Description:** Custom icon configurations for files and folders

| Property                     | Type            | Title/Description                                                  |
| ---------------------------- | --------------- | ------------------------------------------------------------------ |
|   [files](#icons_files )     | array of object | Custom file icon mappings. Earlier entries have higher priority.   |
|   [folders](#icons_folders ) | array of object | Custom folder icon mappings. Earlier entries have higher priority. |

### <a name="icons_files"></a>4.1. Property `Rovr Config > icons > files`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of object` |
| **Required** | No                |
| **Default**  | `[]`              |

**Description:** Custom file icon mappings. Earlier entries have higher priority.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be   | Description |
| --------------------------------- | ----------- |
| [files items](#icons_files_items) |             |

#### <a name="icons_files_items"></a>4.1.1. Rovr Config > icons > files > files items

|                           |                  |
| ------------------------- | ---------------- |
| **Type**                  | `object`         |
| **Required**              | No               |
| **Additional properties** | Any type allowed |

| Property                                       | Type             | Title/Description                                                                                                     |
| ---------------------------------------------- | ---------------- | --------------------------------------------------------------------------------------------------------------------- |
|   [pattern](#icons_files_items_pattern )       | string           | The file name pattern to match                                                                                        |
|   [match_type](#icons_files_items_match_type ) | enum (of string) | Type of matching:<br />\`exact\`   : for exact file name matching<br />\`endswith\`: for file name ends with matching |
|   [icon](#icons_files_items_icon )             | string           | The icon character to use.                                                                                            |
|   [color](#icons_files_items_color )           | string           | The color for the icon. Can be a named color or hex code.                                                             |

##### <a name="icons_files_items_pattern"></a>4.1.1.1. Property `Rovr Config > icons > files > files items > pattern`

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | Yes      |

**Description:** The file name pattern to match

##### <a name="icons_files_items_match_type"></a>4.1.1.2. Property `Rovr Config > icons > files > files items > match_type`

|              |                    |
| ------------ | ------------------ |
| **Type**     | `enum (of string)` |
| **Required** | Yes                |
| **Default**  | `"exact"`          |

**Description:** Type of matching:
`exact`   : for exact file name matching
`endswith`: for file name ends with matching

Must be one of:
* "exact"
* "endswith"

##### <a name="icons_files_items_icon"></a>4.1.1.3. Property `Rovr Config > icons > files > files items > icon`

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | Yes      |

**Description:** The icon character to use.

##### <a name="icons_files_items_color"></a>4.1.1.4. Property `Rovr Config > icons > files > files items > color`

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | Yes      |

**Description:** The color for the icon. Can be a named color or hex code.

### <a name="icons_folders"></a>4.2. Property `Rovr Config > icons > folders`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of object` |
| **Required** | No                |
| **Default**  | `[]`              |

**Description:** Custom folder icon mappings. Earlier entries have higher priority.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be       | Description |
| ------------------------------------- | ----------- |
| [folders items](#icons_folders_items) |             |

#### <a name="icons_folders_items"></a>4.2.1. Rovr Config > icons > folders > folders items

|                           |                  |
| ------------------------- | ---------------- |
| **Type**                  | `object`         |
| **Required**              | No               |
| **Additional properties** | Any type allowed |

| Property                                         | Type             | Title/Description                                                                                                     |
| ------------------------------------------------ | ---------------- | --------------------------------------------------------------------------------------------------------------------- |
|   [pattern](#icons_folders_items_pattern )       | string           | The folder name pattern to match                                                                                      |
|   [match_type](#icons_folders_items_match_type ) | enum (of string) | Type of matching:<br />\`exact\`   : for exact file name matching<br />\`endswith\`: for file name ends with matching |
|   [icon](#icons_folders_items_icon )             | string           | The icon character to use (should be a nerd font character)                                                           |
|   [color](#icons_folders_items_color )           | string           | The color for the icon. Can be a named color or hex code                                                              |

##### <a name="icons_folders_items_pattern"></a>4.2.1.1. Property `Rovr Config > icons > folders > folders items > pattern`

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | Yes      |

**Description:** The folder name pattern to match

##### <a name="icons_folders_items_match_type"></a>4.2.1.2. Property `Rovr Config > icons > folders > folders items > match_type`

|              |                    |
| ------------ | ------------------ |
| **Type**     | `enum (of string)` |
| **Required** | Yes                |
| **Default**  | `"exact"`          |

**Description:** Type of matching:
`exact`   : for exact file name matching
`endswith`: for file name ends with matching

Must be one of:
* "exact"
* "endswith"

##### <a name="icons_folders_items_icon"></a>4.2.1.3. Property `Rovr Config > icons > folders > folders items > icon`

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | Yes      |

**Description:** The icon character to use (should be a nerd font character)

##### <a name="icons_folders_items_color"></a>4.2.1.4. Property `Rovr Config > icons > folders > folders items > color`

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | Yes      |

**Description:** The color for the icon. Can be a named color or hex code

## <a name="theme"></a>5. Property `Rovr Config > theme`

|                           |             |
| ------------------------- | ----------- |
| **Type**                  | `object`    |
| **Required**              | No          |
| **Additional properties** | Not allowed |

| Property                             | Type    | Title/Description                                                          |
| ------------------------------------ | ------- | -------------------------------------------------------------------------- |
|   [default](#theme_default )         | string  | The default theme. Can be changed while in rovr, but it is not persistent. |
|   [transparent](#theme_transparent ) | boolean | Use a transparent background.                                              |

### <a name="theme_default"></a>5.1. Property `Rovr Config > theme > default`

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |
| **Default**  | `"nord"` |

**Description:** The default theme. Can be changed while in rovr, but it is not persistent.

### <a name="theme_transparent"></a>5.2. Property `Rovr Config > theme > transparent`

|              |           |
| ------------ | --------- |
| **Type**     | `boolean` |
| **Required** | No        |
| **Default**  | `false`   |

**Description:** Use a transparent background.

## <a name="custom_theme"></a>6. Property `Rovr Config > custom_theme`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of object` |
| **Required** | No                |

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be           | Description |
| ----------------------------------------- | ----------- |
| [custom_theme items](#custom_theme_items) |             |

### <a name="custom_theme_items"></a>6.1. Rovr Config > custom_theme > custom_theme items

|                           |             |
| ------------------------- | ----------- |
| **Type**                  | `object`    |
| **Required**              | No          |
| **Additional properties** | Not allowed |

| Property                                        | Type    | Title/Description                                                                                                                                    |
| ----------------------------------------------- | ------- | ---------------------------------------------------------------------------------------------------------------------------------------------------- |
|   [name](#custom_theme_items_name )             | string  | A name for the theme. However, when the theme is available in the theme picker, it shows up as a hiphenated, lowercase version.                      |
|   [primary](#custom_theme_items_primary )       | string  | A hex code or named color to use as the primary color. Refer to https://textual.textualize.io/css_types/color/#named-colors for the named colors.    |
|   [secondary](#custom_theme_items_secondary )   | string  | A hex code or named color to use as the secondary color. Refer to https://textual.textualize.io/css_types/color/#named-colors for the named colors.  |
|   [warning](#custom_theme_items_warning )       | string  | A hex code or named color to use as the warning color. Refer to https://textual.textualize.io/css_types/color/#named-colors for the named colors.    |
|   [error](#custom_theme_items_error )           | string  | A hex code or named color to use as the error color. Refer to https://textual.textualize.io/css_types/color/#named-colors for the named colors.      |
|   [success](#custom_theme_items_success )       | string  | A hex code or named color to use as the success color. Refer to https://textual.textualize.io/css_types/color/#named-colors for the named colors.    |
|   [accent](#custom_theme_items_accent )         | string  | A hex code or named color to use as the accent color. Refer to https://textual.textualize.io/css_types/color/#named-colors for the named colors.     |
|   [foreground](#custom_theme_items_foreground ) | string  | A hex code or named color to use as the foreground color. Refer to https://textual.textualize.io/css_types/color/#named-colors for the named colors. |
|   [background](#custom_theme_items_background ) | string  | A hex code or named color to use as the background color. Refer to https://textual.textualize.io/css_types/color/#named-colors for the named colors. |
|   [surface](#custom_theme_items_surface )       | string  | A hex code or named color to use as the surface color. Refer to https://textual.textualize.io/css_types/color/#named-colors for the named colors.    |
|   [panel](#custom_theme_items_panel )           | string  | A hex code or named color to use as the panel color. Refer to https://textual.textualize.io/css_types/color/#named-colors for the named colors.      |
|   [is_dark](#custom_theme_items_is_dark )       | boolean | Whether or not this theme is a dark type theme.                                                                                                      |
|   [variables](#custom_theme_items_variables )   | object  | Extra variables to set unique to the theme.<br />Refer to https://textual.textualize.io/guide/design/#additional-variables for more information.     |

#### <a name="custom_theme_items_name"></a>6.1.1. Property `Rovr Config > custom_theme > custom_theme items > name`

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | Yes      |

**Description:** A name for the theme. However, when the theme is available in the theme picker, it shows up as a hiphenated, lowercase version.

#### <a name="custom_theme_items_primary"></a>6.1.2. Property `Rovr Config > custom_theme > custom_theme items > primary`

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | Yes      |

**Description:** A hex code or named color to use as the primary color. Refer to https://textual.textualize.io/css_types/color/#named-colors for the named colors.

#### <a name="custom_theme_items_secondary"></a>6.1.3. Property `Rovr Config > custom_theme > custom_theme items > secondary`

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | Yes      |

**Description:** A hex code or named color to use as the secondary color. Refer to https://textual.textualize.io/css_types/color/#named-colors for the named colors.

#### <a name="custom_theme_items_warning"></a>6.1.4. Property `Rovr Config > custom_theme > custom_theme items > warning`

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | Yes      |

**Description:** A hex code or named color to use as the warning color. Refer to https://textual.textualize.io/css_types/color/#named-colors for the named colors.

#### <a name="custom_theme_items_error"></a>6.1.5. Property `Rovr Config > custom_theme > custom_theme items > error`

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | Yes      |

**Description:** A hex code or named color to use as the error color. Refer to https://textual.textualize.io/css_types/color/#named-colors for the named colors.

#### <a name="custom_theme_items_success"></a>6.1.6. Property `Rovr Config > custom_theme > custom_theme items > success`

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | Yes      |

**Description:** A hex code or named color to use as the success color. Refer to https://textual.textualize.io/css_types/color/#named-colors for the named colors.

#### <a name="custom_theme_items_accent"></a>6.1.7. Property `Rovr Config > custom_theme > custom_theme items > accent`

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | Yes      |

**Description:** A hex code or named color to use as the accent color. Refer to https://textual.textualize.io/css_types/color/#named-colors for the named colors.

#### <a name="custom_theme_items_foreground"></a>6.1.8. Property `Rovr Config > custom_theme > custom_theme items > foreground`

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | Yes      |

**Description:** A hex code or named color to use as the foreground color. Refer to https://textual.textualize.io/css_types/color/#named-colors for the named colors.

#### <a name="custom_theme_items_background"></a>6.1.9. Property `Rovr Config > custom_theme > custom_theme items > background`

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | Yes      |

**Description:** A hex code or named color to use as the background color. Refer to https://textual.textualize.io/css_types/color/#named-colors for the named colors.

#### <a name="custom_theme_items_surface"></a>6.1.10. Property `Rovr Config > custom_theme > custom_theme items > surface`

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | Yes      |

**Description:** A hex code or named color to use as the surface color. Refer to https://textual.textualize.io/css_types/color/#named-colors for the named colors.

#### <a name="custom_theme_items_panel"></a>6.1.11. Property `Rovr Config > custom_theme > custom_theme items > panel`

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | Yes      |

**Description:** A hex code or named color to use as the panel color. Refer to https://textual.textualize.io/css_types/color/#named-colors for the named colors.

#### <a name="custom_theme_items_is_dark"></a>6.1.12. Property `Rovr Config > custom_theme > custom_theme items > is_dark`

|              |           |
| ------------ | --------- |
| **Type**     | `boolean` |
| **Required** | Yes       |

**Description:** Whether or not this theme is a dark type theme.

#### <a name="custom_theme_items_variables"></a>6.1.13. Property `Rovr Config > custom_theme > custom_theme items > variables`

|                           |                  |
| ------------------------- | ---------------- |
| **Type**                  | `object`         |
| **Required**              | No               |
| **Additional properties** | Any type allowed |

**Description:** Extra variables to set unique to the theme.
Refer to https://textual.textualize.io/guide/design/#additional-variables for more information.

| Property                                                  | Type   | Title/Description |
| --------------------------------------------------------- | ------ | ----------------- |
|   [](#custom_theme_items_variables_additionalProperties ) | object |                   |

## <a name="keybinds"></a>7. Property `Rovr Config > keybinds`

|                           |             |
| ------------------------- | ----------- |
| **Type**                  | `object`    |
| **Required**              | No          |
| **Additional properties** | Not allowed |

| Property                                                                  | Type            | Title/Description                                                                                                              |
| ------------------------------------------------------------------------- | --------------- | ------------------------------------------------------------------------------------------------------------------------------ |
|   [toggle_pin](#keybinds_toggle_pin )                                     | array of string | Toggle the current folder in the Pinned Folder Sidebar.                                                                        |
|   [toggle_pinned_sidebar](#keybinds_toggle_pinned_sidebar )               | array of string | Toggle viewing the pinned sidebar.                                                                                             |
|   [toggle_preview_sidebar](#keybinds_toggle_preview_sidebar )             | array of string | Toggle viewing the preview sidebar.                                                                                            |
|   [toggle_footer](#keybinds_toggle_footer )                               | array of string | Toggle viewing the footer.                                                                                                     |
|   [focus_toggle_pinned_sidebar](#keybinds_focus_toggle_pinned_sidebar )   | array of string | Toggle focus between pinned folder sidebar and file list.                                                                      |
|   [focus_file_list](#keybinds_focus_file_list )                           | array of string | Focus the file list.                                                                                                           |
|   [focus_toggle_preview_sidebar](#keybinds_focus_toggle_preview_sidebar ) | array of string | Focus toggle between preview sidebar and file list.                                                                            |
|   [focus_toggle_path_switcher](#keybinds_focus_toggle_path_switcher )     | array of string | Focus toggle between path switcher and file list.                                                                              |
|   [focus_toggle_processes](#keybinds_focus_toggle_processes )             | array of string | Focus toggle the processes container.                                                                                          |
|   [focus_toggle_clipboard](#keybinds_focus_toggle_clipboard )             | array of string | Focus toggle the clipboard container.                                                                                          |
|   [focus_toggle_metadata](#keybinds_focus_toggle_metadata )               | array of string | Focus toggle the metadata container.                                                                                           |
|   [focus_search](#keybinds_focus_search )                                 | array of string | Focus the search bar.                                                                                                          |
|   [copy](#keybinds_copy )                                                 | array of string | Copy the selected files in the file list to the clipboard.                                                                     |
|   [paste](#keybinds_paste )                                               | array of string | Paste the selected files in the clipboard into the current directory.                                                          |
|   [cut](#keybinds_cut )                                                   | array of string | Cut the selected files in the file list to the clipboard.                                                                      |
|   [delete](#keybinds_delete )                                             | array of string | Delete the selected files in the file list.                                                                                    |
|   [rename](#keybinds_rename )                                             | array of string | Rename the selected file in the file list to something else.                                                                   |
|   [new](#keybinds_new )                                                   | array of string | Create a new item in the current directory.                                                                                    |
|   [toggle_all](#keybinds_toggle_all )                                     | array of string | Enter into select mode and select/unselect everything.                                                                         |
|   [zip](#keybinds_zip )                                                   | array of string | Create a zip archive from selected files.                                                                                      |
|   [unzip](#keybinds_unzip )                                               | array of string | Extract a selected zip archive.                                                                                                |
|   [up](#keybinds_up )                                                     | array of string | Go up the file list options.                                                                                                   |
|   [down](#keybinds_down )                                                 | array of string | Go down the file list options.                                                                                                 |
|   [up_tree](#keybinds_up_tree )                                           | array of string | Go up the file tree.                                                                                                           |
|   [down_tree](#keybinds_down_tree )                                       | array of string | Go down the file tree, or open the currently selected item.                                                                    |
|   [page_up](#keybinds_page_up )                                           | array of string | Page Up in the file list options.                                                                                              |
|   [page_down](#keybinds_page_down )                                       | array of string | Page Down in the file list options.                                                                                            |
|   [home](#keybinds_home )                                                 | array of string | Go to the first option in the file list options.                                                                               |
|   [end](#keybinds_end )                                                   | array of string | Go to the last option in the file list options.                                                                                |
|   [hist_previous](#keybinds_hist_previous )                               | array of string | Go back in history.                                                                                                            |
|   [hist_next](#keybinds_hist_next )                                       | array of string | Go forward in history.                                                                                                         |
|   [toggle_visual](#keybinds_toggle_visual )                               | array of string | Enter or exit select/visual mode.                                                                                              |
|   [select_up](#keybinds_select_up )                                       | array of string | While in visual mode, extend the selection up.                                                                                 |
|   [select_down](#keybinds_select_down )                                   | array of string | While in visual mode, extend the selection down.                                                                               |
|   [select_page_up](#keybinds_select_page_up )                             | array of string | While in visual mode, extend the selection to the previous page.                                                               |
|   [select_page_down](#keybinds_select_page_down )                         | array of string | While in visual mode, extend the selection to the next page.                                                                   |
|   [select_home](#keybinds_select_home )                                   | array of string | While in visual mode, extend the selection to the first option.                                                                |
|   [select_end](#keybinds_select_end )                                     | array of string | While in visual mode, extend the selection to the last option.                                                                 |
|   [tab_next](#keybinds_tab_next )                                         | array of string | Go to the next tab, if it is available.                                                                                        |
|   [tab_previous](#keybinds_tab_previous )                                 | array of string | Go to the previous tab, if it is available.                                                                                    |
|   [tab_new](#keybinds_tab_new )                                           | array of string | Create a new tab.                                                                                                              |
|   [tab_close](#keybinds_tab_close )                                       | array of string | Close the current tab.                                                                                                         |
|   [preview_scroll_left](#keybinds_preview_scroll_left )                   | array of string | While using \`settings.preview_full = true\`, and the preview container is focused, scroll left when this keybind is pressed.  |
|   [preview_scroll_right](#keybinds_preview_scroll_right )                 | array of string | While using \`settings.preview_full = true\`, and the preview container is focused, scroll right when this keybind is pressed. |
|   [preview_select_right](#keybinds_preview_select_right )                 | array of string | While using TextArea for previewing, use this keybind to extend selection to the right.                                        |
|   [preview_select_left](#keybinds_preview_select_left )                   | array of string | While using TextArea for previewing, use this keybind to extend selection to the left.                                         |

### <a name="keybinds_toggle_pin"></a>7.1. Property `Rovr Config > keybinds > toggle_pin`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Toggle the current folder in the Pinned Folder Sidebar.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                | Description |
| ---------------------------------------------- | ----------- |
| [toggle_pin items](#keybinds_toggle_pin_items) |             |

#### <a name="keybinds_toggle_pin_items"></a>7.1.1. Rovr Config > keybinds > toggle_pin > toggle_pin items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_toggle_pinned_sidebar"></a>7.2. Property `Rovr Config > keybinds > toggle_pinned_sidebar`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Toggle viewing the pinned sidebar.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                                      | Description |
| -------------------------------------------------------------------- | ----------- |
| [toggle_pinned_sidebar items](#keybinds_toggle_pinned_sidebar_items) |             |

#### <a name="keybinds_toggle_pinned_sidebar_items"></a>7.2.1. Rovr Config > keybinds > toggle_pinned_sidebar > toggle_pinned_sidebar items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_toggle_preview_sidebar"></a>7.3. Property `Rovr Config > keybinds > toggle_preview_sidebar`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Toggle viewing the preview sidebar.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                                        | Description |
| ---------------------------------------------------------------------- | ----------- |
| [toggle_preview_sidebar items](#keybinds_toggle_preview_sidebar_items) |             |

#### <a name="keybinds_toggle_preview_sidebar_items"></a>7.3.1. Rovr Config > keybinds > toggle_preview_sidebar > toggle_preview_sidebar items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_toggle_footer"></a>7.4. Property `Rovr Config > keybinds > toggle_footer`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Toggle viewing the footer.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                      | Description |
| ---------------------------------------------------- | ----------- |
| [toggle_footer items](#keybinds_toggle_footer_items) |             |

#### <a name="keybinds_toggle_footer_items"></a>7.4.1. Rovr Config > keybinds > toggle_footer > toggle_footer items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_focus_toggle_pinned_sidebar"></a>7.5. Property `Rovr Config > keybinds > focus_toggle_pinned_sidebar`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Toggle focus between pinned folder sidebar and file list.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                                                  | Description |
| -------------------------------------------------------------------------------- | ----------- |
| [focus_toggle_pinned_sidebar items](#keybinds_focus_toggle_pinned_sidebar_items) |             |

#### <a name="keybinds_focus_toggle_pinned_sidebar_items"></a>7.5.1. Rovr Config > keybinds > focus_toggle_pinned_sidebar > focus_toggle_pinned_sidebar items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_focus_file_list"></a>7.6. Property `Rovr Config > keybinds > focus_file_list`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Focus the file list.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                          | Description |
| -------------------------------------------------------- | ----------- |
| [focus_file_list items](#keybinds_focus_file_list_items) |             |

#### <a name="keybinds_focus_file_list_items"></a>7.6.1. Rovr Config > keybinds > focus_file_list > focus_file_list items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_focus_toggle_preview_sidebar"></a>7.7. Property `Rovr Config > keybinds > focus_toggle_preview_sidebar`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Focus toggle between preview sidebar and file list.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                                                    | Description |
| ---------------------------------------------------------------------------------- | ----------- |
| [focus_toggle_preview_sidebar items](#keybinds_focus_toggle_preview_sidebar_items) |             |

#### <a name="keybinds_focus_toggle_preview_sidebar_items"></a>7.7.1. Rovr Config > keybinds > focus_toggle_preview_sidebar > focus_toggle_preview_sidebar items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_focus_toggle_path_switcher"></a>7.8. Property `Rovr Config > keybinds > focus_toggle_path_switcher`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Focus toggle between path switcher and file list.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                                                | Description |
| ------------------------------------------------------------------------------ | ----------- |
| [focus_toggle_path_switcher items](#keybinds_focus_toggle_path_switcher_items) |             |

#### <a name="keybinds_focus_toggle_path_switcher_items"></a>7.8.1. Rovr Config > keybinds > focus_toggle_path_switcher > focus_toggle_path_switcher items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_focus_toggle_processes"></a>7.9. Property `Rovr Config > keybinds > focus_toggle_processes`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Focus toggle the processes container.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                                        | Description |
| ---------------------------------------------------------------------- | ----------- |
| [focus_toggle_processes items](#keybinds_focus_toggle_processes_items) |             |

#### <a name="keybinds_focus_toggle_processes_items"></a>7.9.1. Rovr Config > keybinds > focus_toggle_processes > focus_toggle_processes items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_focus_toggle_clipboard"></a>7.10. Property `Rovr Config > keybinds > focus_toggle_clipboard`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Focus toggle the clipboard container.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                                        | Description |
| ---------------------------------------------------------------------- | ----------- |
| [focus_toggle_clipboard items](#keybinds_focus_toggle_clipboard_items) |             |

#### <a name="keybinds_focus_toggle_clipboard_items"></a>7.10.1. Rovr Config > keybinds > focus_toggle_clipboard > focus_toggle_clipboard items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_focus_toggle_metadata"></a>7.11. Property `Rovr Config > keybinds > focus_toggle_metadata`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Focus toggle the metadata container.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                                      | Description |
| -------------------------------------------------------------------- | ----------- |
| [focus_toggle_metadata items](#keybinds_focus_toggle_metadata_items) |             |

#### <a name="keybinds_focus_toggle_metadata_items"></a>7.11.1. Rovr Config > keybinds > focus_toggle_metadata > focus_toggle_metadata items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_focus_search"></a>7.12. Property `Rovr Config > keybinds > focus_search`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Focus the search bar.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                    | Description |
| -------------------------------------------------- | ----------- |
| [focus_search items](#keybinds_focus_search_items) |             |

#### <a name="keybinds_focus_search_items"></a>7.12.1. Rovr Config > keybinds > focus_search > focus_search items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_copy"></a>7.13. Property `Rovr Config > keybinds > copy`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Copy the selected files in the file list to the clipboard.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be    | Description |
| ---------------------------------- | ----------- |
| [copy items](#keybinds_copy_items) |             |

#### <a name="keybinds_copy_items"></a>7.13.1. Rovr Config > keybinds > copy > copy items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_paste"></a>7.14. Property `Rovr Config > keybinds > paste`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Paste the selected files in the clipboard into the current directory.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be      | Description |
| ------------------------------------ | ----------- |
| [paste items](#keybinds_paste_items) |             |

#### <a name="keybinds_paste_items"></a>7.14.1. Rovr Config > keybinds > paste > paste items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_cut"></a>7.15. Property `Rovr Config > keybinds > cut`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Cut the selected files in the file list to the clipboard.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be  | Description |
| -------------------------------- | ----------- |
| [cut items](#keybinds_cut_items) |             |

#### <a name="keybinds_cut_items"></a>7.15.1. Rovr Config > keybinds > cut > cut items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_delete"></a>7.16. Property `Rovr Config > keybinds > delete`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Delete the selected files in the file list.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be        | Description |
| -------------------------------------- | ----------- |
| [delete items](#keybinds_delete_items) |             |

#### <a name="keybinds_delete_items"></a>7.16.1. Rovr Config > keybinds > delete > delete items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_rename"></a>7.17. Property `Rovr Config > keybinds > rename`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Rename the selected file in the file list to something else.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be        | Description |
| -------------------------------------- | ----------- |
| [rename items](#keybinds_rename_items) |             |

#### <a name="keybinds_rename_items"></a>7.17.1. Rovr Config > keybinds > rename > rename items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_new"></a>7.18. Property `Rovr Config > keybinds > new`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Create a new item in the current directory.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be  | Description |
| -------------------------------- | ----------- |
| [new items](#keybinds_new_items) |             |

#### <a name="keybinds_new_items"></a>7.18.1. Rovr Config > keybinds > new > new items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_toggle_all"></a>7.19. Property `Rovr Config > keybinds > toggle_all`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Enter into select mode and select/unselect everything.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                | Description |
| ---------------------------------------------- | ----------- |
| [toggle_all items](#keybinds_toggle_all_items) |             |

#### <a name="keybinds_toggle_all_items"></a>7.19.1. Rovr Config > keybinds > toggle_all > toggle_all items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_zip"></a>7.20. Property `Rovr Config > keybinds > zip`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Create a zip archive from selected files.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be  | Description |
| -------------------------------- | ----------- |
| [zip items](#keybinds_zip_items) |             |

#### <a name="keybinds_zip_items"></a>7.20.1. Rovr Config > keybinds > zip > zip items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_unzip"></a>7.21. Property `Rovr Config > keybinds > unzip`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Extract a selected zip archive.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be      | Description |
| ------------------------------------ | ----------- |
| [unzip items](#keybinds_unzip_items) |             |

#### <a name="keybinds_unzip_items"></a>7.21.1. Rovr Config > keybinds > unzip > unzip items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_up"></a>7.22. Property `Rovr Config > keybinds > up`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Go up the file list options.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be | Description |
| ------------------------------- | ----------- |
| [up items](#keybinds_up_items)  |             |

#### <a name="keybinds_up_items"></a>7.22.1. Rovr Config > keybinds > up > up items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_down"></a>7.23. Property `Rovr Config > keybinds > down`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Go down the file list options.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be    | Description |
| ---------------------------------- | ----------- |
| [down items](#keybinds_down_items) |             |

#### <a name="keybinds_down_items"></a>7.23.1. Rovr Config > keybinds > down > down items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_up_tree"></a>7.24. Property `Rovr Config > keybinds > up_tree`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Go up the file tree.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be          | Description |
| ---------------------------------------- | ----------- |
| [up_tree items](#keybinds_up_tree_items) |             |

#### <a name="keybinds_up_tree_items"></a>7.24.1. Rovr Config > keybinds > up_tree > up_tree items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_down_tree"></a>7.25. Property `Rovr Config > keybinds > down_tree`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Go down the file tree, or open the currently selected item.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be              | Description |
| -------------------------------------------- | ----------- |
| [down_tree items](#keybinds_down_tree_items) |             |

#### <a name="keybinds_down_tree_items"></a>7.25.1. Rovr Config > keybinds > down_tree > down_tree items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_page_up"></a>7.26. Property `Rovr Config > keybinds > page_up`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Page Up in the file list options.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be          | Description |
| ---------------------------------------- | ----------- |
| [page_up items](#keybinds_page_up_items) |             |

#### <a name="keybinds_page_up_items"></a>7.26.1. Rovr Config > keybinds > page_up > page_up items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_page_down"></a>7.27. Property `Rovr Config > keybinds > page_down`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Page Down in the file list options.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be              | Description |
| -------------------------------------------- | ----------- |
| [page_down items](#keybinds_page_down_items) |             |

#### <a name="keybinds_page_down_items"></a>7.27.1. Rovr Config > keybinds > page_down > page_down items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_home"></a>7.28. Property `Rovr Config > keybinds > home`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Go to the first option in the file list options.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be    | Description |
| ---------------------------------- | ----------- |
| [home items](#keybinds_home_items) |             |

#### <a name="keybinds_home_items"></a>7.28.1. Rovr Config > keybinds > home > home items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_end"></a>7.29. Property `Rovr Config > keybinds > end`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Go to the last option in the file list options.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be  | Description |
| -------------------------------- | ----------- |
| [end items](#keybinds_end_items) |             |

#### <a name="keybinds_end_items"></a>7.29.1. Rovr Config > keybinds > end > end items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_hist_previous"></a>7.30. Property `Rovr Config > keybinds > hist_previous`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Go back in history.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                      | Description |
| ---------------------------------------------------- | ----------- |
| [hist_previous items](#keybinds_hist_previous_items) |             |

#### <a name="keybinds_hist_previous_items"></a>7.30.1. Rovr Config > keybinds > hist_previous > hist_previous items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_hist_next"></a>7.31. Property `Rovr Config > keybinds > hist_next`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Go forward in history.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be              | Description |
| -------------------------------------------- | ----------- |
| [hist_next items](#keybinds_hist_next_items) |             |

#### <a name="keybinds_hist_next_items"></a>7.31.1. Rovr Config > keybinds > hist_next > hist_next items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_toggle_visual"></a>7.32. Property `Rovr Config > keybinds > toggle_visual`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Enter or exit select/visual mode.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                      | Description |
| ---------------------------------------------------- | ----------- |
| [toggle_visual items](#keybinds_toggle_visual_items) |             |

#### <a name="keybinds_toggle_visual_items"></a>7.32.1. Rovr Config > keybinds > toggle_visual > toggle_visual items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_select_up"></a>7.33. Property `Rovr Config > keybinds > select_up`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** While in visual mode, extend the selection up.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be              | Description |
| -------------------------------------------- | ----------- |
| [select_up items](#keybinds_select_up_items) |             |

#### <a name="keybinds_select_up_items"></a>7.33.1. Rovr Config > keybinds > select_up > select_up items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_select_down"></a>7.34. Property `Rovr Config > keybinds > select_down`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** While in visual mode, extend the selection down.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                  | Description |
| ------------------------------------------------ | ----------- |
| [select_down items](#keybinds_select_down_items) |             |

#### <a name="keybinds_select_down_items"></a>7.34.1. Rovr Config > keybinds > select_down > select_down items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_select_page_up"></a>7.35. Property `Rovr Config > keybinds > select_page_up`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** While in visual mode, extend the selection to the previous page.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                        | Description |
| ------------------------------------------------------ | ----------- |
| [select_page_up items](#keybinds_select_page_up_items) |             |

#### <a name="keybinds_select_page_up_items"></a>7.35.1. Rovr Config > keybinds > select_page_up > select_page_up items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_select_page_down"></a>7.36. Property `Rovr Config > keybinds > select_page_down`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** While in visual mode, extend the selection to the next page.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                            | Description |
| ---------------------------------------------------------- | ----------- |
| [select_page_down items](#keybinds_select_page_down_items) |             |

#### <a name="keybinds_select_page_down_items"></a>7.36.1. Rovr Config > keybinds > select_page_down > select_page_down items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_select_home"></a>7.37. Property `Rovr Config > keybinds > select_home`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** While in visual mode, extend the selection to the first option.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                  | Description |
| ------------------------------------------------ | ----------- |
| [select_home items](#keybinds_select_home_items) |             |

#### <a name="keybinds_select_home_items"></a>7.37.1. Rovr Config > keybinds > select_home > select_home items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_select_end"></a>7.38. Property `Rovr Config > keybinds > select_end`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** While in visual mode, extend the selection to the last option.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                | Description |
| ---------------------------------------------- | ----------- |
| [select_end items](#keybinds_select_end_items) |             |

#### <a name="keybinds_select_end_items"></a>7.38.1. Rovr Config > keybinds > select_end > select_end items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_tab_next"></a>7.39. Property `Rovr Config > keybinds > tab_next`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Go to the next tab, if it is available.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be            | Description |
| ------------------------------------------ | ----------- |
| [tab_next items](#keybinds_tab_next_items) |             |

#### <a name="keybinds_tab_next_items"></a>7.39.1. Rovr Config > keybinds > tab_next > tab_next items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_tab_previous"></a>7.40. Property `Rovr Config > keybinds > tab_previous`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Go to the previous tab, if it is available.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                    | Description |
| -------------------------------------------------- | ----------- |
| [tab_previous items](#keybinds_tab_previous_items) |             |

#### <a name="keybinds_tab_previous_items"></a>7.40.1. Rovr Config > keybinds > tab_previous > tab_previous items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_tab_new"></a>7.41. Property `Rovr Config > keybinds > tab_new`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Create a new tab.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be          | Description |
| ---------------------------------------- | ----------- |
| [tab_new items](#keybinds_tab_new_items) |             |

#### <a name="keybinds_tab_new_items"></a>7.41.1. Rovr Config > keybinds > tab_new > tab_new items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_tab_close"></a>7.42. Property `Rovr Config > keybinds > tab_close`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** Close the current tab.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be              | Description |
| -------------------------------------------- | ----------- |
| [tab_close items](#keybinds_tab_close_items) |             |

#### <a name="keybinds_tab_close_items"></a>7.42.1. Rovr Config > keybinds > tab_close > tab_close items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_preview_scroll_left"></a>7.43. Property `Rovr Config > keybinds > preview_scroll_left`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** While using `settings.preview_full = true`, and the preview container is focused, scroll left when this keybind is pressed.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                                  | Description |
| ---------------------------------------------------------------- | ----------- |
| [preview_scroll_left items](#keybinds_preview_scroll_left_items) |             |

#### <a name="keybinds_preview_scroll_left_items"></a>7.43.1. Rovr Config > keybinds > preview_scroll_left > preview_scroll_left items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_preview_scroll_right"></a>7.44. Property `Rovr Config > keybinds > preview_scroll_right`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** While using `settings.preview_full = true`, and the preview container is focused, scroll right when this keybind is pressed.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                                    | Description |
| ------------------------------------------------------------------ | ----------- |
| [preview_scroll_right items](#keybinds_preview_scroll_right_items) |             |

#### <a name="keybinds_preview_scroll_right_items"></a>7.44.1. Rovr Config > keybinds > preview_scroll_right > preview_scroll_right items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_preview_select_right"></a>7.45. Property `Rovr Config > keybinds > preview_select_right`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** While using TextArea for previewing, use this keybind to extend selection to the right.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                                    | Description |
| ------------------------------------------------------------------ | ----------- |
| [preview_select_right items](#keybinds_preview_select_right_items) |             |

#### <a name="keybinds_preview_select_right_items"></a>7.45.1. Rovr Config > keybinds > preview_select_right > preview_select_right items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="keybinds_preview_select_left"></a>7.46. Property `Rovr Config > keybinds > preview_select_left`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |

**Description:** While using TextArea for previewing, use this keybind to extend selection to the left.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                                  | Description |
| ---------------------------------------------------------------- | ----------- |
| [preview_select_left items](#keybinds_preview_select_left_items) |             |

#### <a name="keybinds_preview_select_left_items"></a>7.46.1. Rovr Config > keybinds > preview_select_left > preview_select_left items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

## <a name="plugins"></a>8. Property `Rovr Config > plugins`

|                           |             |
| ------------------------- | ----------- |
| **Type**                  | `object`    |
| **Required**              | No          |
| **Additional properties** | Not allowed |

| Property                         | Type   | Title/Description |
| -------------------------------- | ------ | ----------------- |
|   [zoxide](#plugins_zoxide )     | object |                   |
|   [bat](#plugins_bat )           | object |                   |
|   [editor](#plugins_editor )     | object |                   |
|   [zen_mode](#plugins_zen_mode ) | object |                   |

### <a name="plugins_zoxide"></a>8.1. Property `Rovr Config > plugins > zoxide`

|                           |             |
| ------------------------- | ----------- |
| **Type**                  | `object`    |
| **Required**              | No          |
| **Additional properties** | Not allowed |

| Property                                | Type            | Title/Description                     |
| --------------------------------------- | --------------- | ------------------------------------- |
|   [enabled](#plugins_zoxide_enabled )   | boolean         | Enable or disable zoxide travelling.  |
|   [keybinds](#plugins_zoxide_keybinds ) | array of string | The keybind to open the zoxide modal. |

#### <a name="plugins_zoxide_enabled"></a>8.1.1. Property `Rovr Config > plugins > zoxide > enabled`

|              |           |
| ------------ | --------- |
| **Type**     | `boolean` |
| **Required** | No        |
| **Default**  | `false`   |

**Description:** Enable or disable zoxide travelling.

#### <a name="plugins_zoxide_keybinds"></a>8.1.2. Property `Rovr Config > plugins > zoxide > keybinds`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |
| **Default**  | `["z"]`           |

**Description:** The keybind to open the zoxide modal.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                  | Description |
| ------------------------------------------------ | ----------- |
| [keybinds items](#plugins_zoxide_keybinds_items) |             |

##### <a name="plugins_zoxide_keybinds_items"></a>8.1.2.1. Rovr Config > plugins > zoxide > keybinds > keybinds items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="plugins_bat"></a>8.2. Property `Rovr Config > plugins > bat`

|                           |             |
| ------------------------- | ----------- |
| **Type**                  | `object`    |
| **Required**              | No          |
| **Additional properties** | Not allowed |

| Property                                               | Type    | Title/Description                           |
| ------------------------------------------------------ | ------- | ------------------------------------------- |
|   [enabled](#plugins_bat_enabled )                     | boolean | Enable or disable bat for previewing files. |
|   [executable](#plugins_bat_executable )               | string  | The executable for bat.                     |
|   [show_line_numbers](#plugins_bat_show_line_numbers ) | boolean | Make batcat show line numbers.              |

#### <a name="plugins_bat_enabled"></a>8.2.1. Property `Rovr Config > plugins > bat > enabled`

|              |           |
| ------------ | --------- |
| **Type**     | `boolean` |
| **Required** | No        |
| **Default**  | `false`   |

**Description:** Enable or disable bat for previewing files.

#### <a name="plugins_bat_executable"></a>8.2.2. Property `Rovr Config > plugins > bat > executable`

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |
| **Default**  | `"bat"`  |

**Description:** The executable for bat.

#### <a name="plugins_bat_show_line_numbers"></a>8.2.3. Property `Rovr Config > plugins > bat > show_line_numbers`

|              |           |
| ------------ | --------- |
| **Type**     | `boolean` |
| **Required** | No        |
| **Default**  | `true`    |

**Description:** Make batcat show line numbers.

### <a name="plugins_editor"></a>8.3. Property `Rovr Config > plugins > editor`

|                           |             |
| ------------------------- | ----------- |
| **Type**                  | `object`    |
| **Required**              | No          |
| **Additional properties** | Not allowed |

| Property                                                  | Type            | Title/Description                     |
| --------------------------------------------------------- | --------------- | ------------------------------------- |
|   [enabled](#plugins_editor_enabled )                     | boolean         | Enable opening a file in your editor. |
|   [file_executable](#plugins_editor_file_executable )     | string          | Open files in this app.               |
|   [folder_executable](#plugins_editor_folder_executable ) | string          | Open folders in this app.             |
|   [keybinds](#plugins_editor_keybinds )                   | array of string | The keybind to launch your editor.    |

#### <a name="plugins_editor_enabled"></a>8.3.1. Property `Rovr Config > plugins > editor > enabled`

|              |           |
| ------------ | --------- |
| **Type**     | `boolean` |
| **Required** | No        |
| **Default**  | `true`    |

**Description:** Enable opening a file in your editor.

#### <a name="plugins_editor_file_executable"></a>8.3.2. Property `Rovr Config > plugins > editor > file_executable`

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |
| **Default**  | `"nano"` |

**Description:** Open files in this app.

#### <a name="plugins_editor_folder_executable"></a>8.3.3. Property `Rovr Config > plugins > editor > folder_executable`

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |
| **Default**  | `"code"` |

**Description:** Open folders in this app.

#### <a name="plugins_editor_keybinds"></a>8.3.4. Property `Rovr Config > plugins > editor > keybinds`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |
| **Default**  | `["e"]`           |

**Description:** The keybind to launch your editor.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                  | Description |
| ------------------------------------------------ | ----------- |
| [keybinds items](#plugins_editor_keybinds_items) |             |

##### <a name="plugins_editor_keybinds_items"></a>8.3.4.1. Rovr Config > plugins > editor > keybinds > keybinds items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

### <a name="plugins_zen_mode"></a>8.4. Property `Rovr Config > plugins > zen_mode`

|                           |             |
| ------------------------- | ----------- |
| **Type**                  | `object`    |
| **Required**              | No          |
| **Additional properties** | Not allowed |

| Property                                  | Type            | Title/Description                                                                                    |
| ----------------------------------------- | --------------- | ---------------------------------------------------------------------------------------------------- |
|   [enabled](#plugins_zen_mode_enabled )   | boolean         | Allow enabling or disabling zen mode. Nothing shows up while in zen mode, except only the file list. |
|   [keybinds](#plugins_zen_mode_keybinds ) | array of string | The keybind to toggle zen mode.                                                                      |

#### <a name="plugins_zen_mode_enabled"></a>8.4.1. Property `Rovr Config > plugins > zen_mode > enabled`

|              |           |
| ------------ | --------- |
| **Type**     | `boolean` |
| **Required** | No        |
| **Default**  | `false`   |

**Description:** Allow enabling or disabling zen mode. Nothing shows up while in zen mode, except only the file list.

#### <a name="plugins_zen_mode_keybinds"></a>8.4.2. Property `Rovr Config > plugins > zen_mode > keybinds`

|              |                   |
| ------------ | ----------------- |
| **Type**     | `array of string` |
| **Required** | No                |
| **Default**  | `["Z"]`           |

**Description:** The keybind to toggle zen mode.

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |

| Each item of this array must be                    | Description |
| -------------------------------------------------- | ----------- |
| [keybinds items](#plugins_zen_mode_keybinds_items) |             |

##### <a name="plugins_zen_mode_keybinds_items"></a>8.4.2.1. Rovr Config > plugins > zen_mode > keybinds > keybinds items

|              |          |
| ------------ | -------- |
| **Type**     | `string` |
| **Required** | No       |

----------------------------------------------------------------------------------------------------------------------------
